# OPEN NEW PROJECT
closeProject()
newProject( "T3-3", 10 )
setModelAnalysisAspects( [ "STRUCT" ] )
setModelDimension( "2D" )  
setDefaultMeshOrder( "QUADRATIC" ) 
setDefaultMesherType( "HEXQUAD" )
setUnit( "LENGTH", "MM" )
setUnit( "FORCE", "N" )

# INITIALIZE SHAPE LIST AND SHAPE NUMBERING
SHAPELIST = []
SHAPENUMBER = 1
SELTOL = 0.01

from TOP_FUNC import A_TOP as A_TOP
import os
from math import pi

# SET PARAMETERS

#y-direction
t_STEELPLATE = 50 
h = 600.0 
m2 = 0.3
k2 = (1-m2)/2
OPENINGHEIGHT = m2*h
y1 = k2*h 

#x-direction
OVERHANG = 100.0 
STEELPLATE = 100.0 
a = 300
m1 = 0.25
k1 = (1-m1)/(2)
x1= k1*a -STEELPLATE/2 
OPENINGWIDTH = m1*a

#end plates - steel plate
h_endplate = 100 
t_endplate = 10 

PRESCRIBEDDISPLACEMENT = -4.0 
ELEMENTSIZE =h/12 

#Longitudinal Reinforcement
diam_main = 19 
diamtop = 10 

ASL_19 = 3*((pi/4)*diam_main**2) 
ASL_10= 2*((pi/4)*diamtop**2)  

#WEB REINFORCEMENT
diam_web_bar = 6 
diam_inclweb_bar = 10 
ASL_inclined = 3*((pi/4)*diam_inclweb_bar**2) 
ASSHOR = 2*((pi/4)*diam_web_bar**2) 
ASSVERT_10 = 2*((pi/4)*diamtop**2) 
ASSVERT_6 = 2*((pi/4)*diam_web_bar**2) 
COVER_main = 50
COVER = 25 
COVER2= 50 

#MATERIAL PARAMETERS
YOUNGSMOD = 32400 
POISSONRATIO = 0.15
POISSONRATIO_STEEL = 0.3
FCT = 3.994 
FC = 55.8 
GF = 0.15056 
GC = 37.6406 
BETA = 0.10 
FY_19 = 803.0
FY_10 = 408.0
FY_6 = 483.0
FY_steelplate = 500.0

ES_19 = 194000.0
ES_10 = 195000.0
ES_6 = 199000.0
E_steelplate = 210000.0
EHTOT1 = 0.02*ES_19 
EHTOT2 = 0.02*ES_10
EHTOT3 = 0.02*ES_6
EPSMAX = 0.1 

# ESTABLISH LISTS WITH COORDINATES
XCOORD = [0]
XCOORD.append(XCOORD[0]+t_endplate)
XCOORD.append(XCOORD[1]+OVERHANG-t_endplate)
XCOORD.append(XCOORD[2]+STEELPLATE/2)
XCOORD.append(XCOORD[3]+STEELPLATE/2)
XCOORD.append(XCOORD[4]+x1)
XCOORD.append(XCOORD[5]+OPENINGWIDTH)
XCOORD.append(XCOORD[6]+x1)
XCOORD.append(XCOORD[7]+STEELPLATE/2)
XCOORD.append(XCOORD[8]+STEELPLATE/2)
XCOORD.append(XCOORD[9]+200)
XCOORD.append(XCOORD[10]+STEELPLATE/2)
XCOORD.append(XCOORD[11]+STEELPLATE/2)
XCOORD.append(XCOORD[12]+x1)
XCOORD.append(XCOORD[13]+OPENINGWIDTH)
XCOORD.append(XCOORD[14]+x1)
XCOORD.append(XCOORD[15]+STEELPLATE/2)
XCOORD.append(XCOORD[16]+STEELPLATE/2)
XCOORD.append(XCOORD[17]+OVERHANG-t_endplate)
XCOORD.append(XCOORD[18]+t_endplate)

YCOORD = [0]
YCOORD.append(YCOORD[0]+t_STEELPLATE)
YCOORD.append(YCOORD[1]+h_endplate)
YCOORD.append(YCOORD[2]+y1-h_endplate)
YCOORD.append(YCOORD[3]+OPENINGHEIGHT)
YCOORD.append(YCOORD[4]+y1)
YCOORD.append(YCOORD[5]+t_STEELPLATE)


# CREATE GEOMETRY
SHAPENUMBER = 1
SHAPELIST = []

SHAPENUMBER,SHAPELIST = A_TOP(2,2,17,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(1,3,19,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(1,4,5,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(7,4,7,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(15,4,5,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(1,5,19,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(3,1,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(16,1,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(8,6,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(11,6,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(1,2,1,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(19,2,1,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)

fitAll()

# LONGITUDINAL REINFORCEMENT
P1 = [XCOORD[0],YCOORD[1]+COVER_main,0]
P2 = [XCOORD[19],YCOORD[1]+COVER_main,0]
createLine( 'LONGREINF_ø19', P1, P2 )
P1 = [XCOORD[0]+COVER2,YCOORD[3]-COVER,0] 
P2 = [XCOORD[9]-20,YCOORD[3]-COVER,0]
createLine( 'LONGREINF1_ø10',  P1, P2 )
P3 = [XCOORD[10]+20,YCOORD[3]-COVER,0]  
P4 = [XCOORD[19]-COVER2,YCOORD[3]-COVER,0]
createLine( 'LONGREINF2_ø10',  P3, P4 )
P1 = [XCOORD[0]+COVER2,YCOORD[4]+COVER,0] 
P2 = [XCOORD[9]-20,YCOORD[4]+COVER,0]
createLine( 'LONGREINF3_ø10',  P1, P2 )
P3 = [XCOORD[10]+20,YCOORD[4]+COVER,0]  
P4 = [XCOORD[19]-COVER2,YCOORD[4]+COVER,0]
createLine( 'LONGREINF4_ø10',  P3, P4 )
P1 = [XCOORD[0]+COVER2,YCOORD[5]-COVER,0]
P2 = [XCOORD[19]-COVER2,YCOORD[5]-COVER,0]
createLine( 'LONGREINF5_ø10', P1, P2 )

MAINREINF = ['LONGREINF_ø19']
REINF1 = ['LONGREINF1_ø10']
REINF2 = ['LONGREINF2_ø10']
REINF3 = ['LONGREINF3_ø10']
REINF4 = ['LONGREINF4_ø10']
REINF5 = ['LONGREINF5_ø10']

# HORIZONTAL WEB REINFORCEMENT
S1 = [XCOORD[0]+COVER,YCOORD[3]-COVER2-10,0]
S2 = [XCOORD[19]-COVER,YCOORD[3]-COVER2-10,0]
createLine( 'HOR_WEB1',  S1, S2 )
S1 = [XCOORD[0]+COVER,YCOORD[4]+COVER2+10,0]
S2 = [XCOORD[19]-COVER,YCOORD[4]+COVER2+10,0]
createLine( 'HOR_WEB2',  S1, S2 )

HOR_WEB1 = ['HOR_WEB1']
HOR_WEB2 = ['HOR_WEB2']

#VERTICAL WEB REINFORCEMENT
#Ø10
S1 = [XCOORD[0]+COVER2,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[0]+COVER2,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB1',  S1, S2 )
S1 = [XCOORD[0]+COVER2*2,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[0]+COVER2*2,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB2',  S1, S2 )
S1 = [XCOORD[5]+20,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[5]+20,YCOORD[3]-COVER,0]
createLine( 'VERT_WEB3',  S1, S2 )
S1 = [XCOORD[5]+20,YCOORD[4]+COVER,0]
S2 = [XCOORD[5]+20,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB4',  S1, S2 )
S1 = [XCOORD[6]-20,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[6]-20,YCOORD[3]-COVER,0]
createLine( 'VERT_WEB5',  S1, S2 )
S1 = [XCOORD[6]-20,YCOORD[4]+COVER,0]
S2 = [XCOORD[6]-20,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB6',  S1, S2 )
S1 = [XCOORD[13]+20,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[13]+20,YCOORD[3]-COVER,0]
createLine( 'VERT_WEB7',  S1, S2 )
S1 = [XCOORD[13]+20,YCOORD[4]+COVER,0]
S2 = [XCOORD[13]+20,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB8',  S1, S2 )
S1 = [XCOORD[14]-20,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[14]-20,YCOORD[3]-COVER,0]
createLine( 'VERT_WEB9',  S1, S2 )
S1 = [XCOORD[14]-20,YCOORD[4]+COVER,0]
S2 = [XCOORD[14]-20,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB10',  S1, S2 )
S1 = [XCOORD[19]-COVER2,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[19]-COVER2,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB11',  S1, S2 )
S1 = [XCOORD[19]-COVER2*2,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[19]-COVER2*2,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB12',  S1, S2 )

VERT_WEB1 = ['VERT_WEB1']
VERT_WEB2 = ['VERT_WEB2']
VERT_WEB3 = ['VERT_WEB3']
VERT_WEB4 = ['VERT_WEB4']
VERT_WEB5 = ['VERT_WEB5']
VERT_WEB6 = ['VERT_WEB6']
VERT_WEB7 = ['VERT_WEB7']
VERT_WEB8 = ['VERT_WEB8']
VERT_WEB9 = ['VERT_WEB9']
VERT_WEB10 = ['VERT_WEB10']
VERT_WEB11 = ['VERT_WEB11']
VERT_WEB12 = ['VERT_WEB12']

#Ø6 
S1 = [XCOORD[5]-COVER,YCOORD[1]+COVER_main,0] 
S2 = [XCOORD[5]-COVER,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB13',  S1, S2 ) #1
S1 = [XCOORD[6]+COVER,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[6]+COVER,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB14',  S1, S2 ) #2
S1 = [XCOORD[9]-20,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[9]-20,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB15',  S1, S2 ) #3
S1 = [XCOORD[9]+100,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[9]+100,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB16',  S1, S2 ) #4
S1 = [XCOORD[10]+20,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[10]+20,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB17',  S1, S2 ) #5
S1 = [XCOORD[13]-COVER,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[13]-COVER,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB18',  S1, S2 ) #6
S1 = [XCOORD[14]+COVER,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[14]+COVER,YCOORD[5]-COVER,0]
createLine( 'VERT_WEB19',  S1, S2 ) #7

VERT_WEB13 = ['VERT_WEB13']
VERT_WEB14 = ['VERT_WEB14']
VERT_WEB15 = ['VERT_WEB15']
VERT_WEB16 = ['VERT_WEB16']
VERT_WEB17 = ['VERT_WEB17']
VERT_WEB18 = ['VERT_WEB18']
VERT_WEB19 = ['VERT_WEB19']

#Inclined/diagonal reinforcement Ø10

S1 = [XCOORD[5],YCOORD[1]+COVER_main,0]
S2 = [XCOORD[0]+COVER2,YCOORD[1]+150+k1*a,0]
createLine( 'diag_WEB1',  S1, S2 )
S1 = [XCOORD[5]+50,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[0]+COVER2,YCOORD[1]+150+k1*a+50,0]
createLine( 'diag_WEB2',  S1, S2 )
S1 = [XCOORD[5]+50*2,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[0]+COVER2,YCOORD[1]+150+k1*a+100,0]
createLine( 'diag_WEB3',  S1, S2 )

diag_WEB1 = ['diag_WEB1']
diag_WEB2 = ['diag_WEB2']
diag_WEB3 = ['diag_WEB3']


S1 = [XCOORD[14],YCOORD[1]+COVER_main,0]
S2 = [XCOORD[19]-COVER2,YCOORD[1]+150+k1*a,0]
createLine( 'diag_WEB4',  S1, S2 )
S1 = [XCOORD[14]-50,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[19]-COVER2,YCOORD[1]+150+k1*a+50,0]
createLine( 'diag_WEB5',  S1, S2 )
S1 = [XCOORD[14]-100,YCOORD[1]+COVER_main,0]
S2 = [XCOORD[19]-COVER2,YCOORD[1]+150+k1*a+100,0]
createLine( 'diag_WEB6',  S1, S2 )

diag_WEB4 = ['diag_WEB4']
diag_WEB5 = ['diag_WEB5']
diag_WEB6 = ['diag_WEB6']

S1 = [XCOORD[0]+150+k1*a+10,YCOORD[5]-COVER,0]
S2 = [XCOORD[9]+100,YCOORD[1]+247.5,0]
createLine( 'diag_WEB7',  S1, S2 )
S1 = [XCOORD[0]+150+k1*a+60,YCOORD[5]-COVER,0]
S2 = [XCOORD[9]+100,YCOORD[1]+247.5+50,0]
createLine( 'diag_WEB8',  S1, S2 )
S1 = [XCOORD[0]+150+k1*a+110,YCOORD[5]-COVER,0]
S2 = [XCOORD[9]+100,YCOORD[1]+247.5+100,0]
createLine( 'diag_WEB9',  S1, S2 )

diag_WEB7 = ['diag_WEB7']
diag_WEB8 = ['diag_WEB8']
diag_WEB9 = ['diag_WEB9']


S1 = [XCOORD[14]-10,YCOORD[5]-COVER,0]
S2 = [XCOORD[9]+100,YCOORD[1]+247.5,0]
createLine( 'diag_WEB10',  S1, S2 )
S1 = [XCOORD[14]-60,YCOORD[5]-COVER,0]
S2 = [XCOORD[9]+100,YCOORD[1]+247.5+50,0]
createLine( 'diag_WEB11',  S1, S2 )
S1 = [XCOORD[14]-110,YCOORD[5]-COVER,0]
S2 = [XCOORD[9]+100,YCOORD[1]+247.5+100,0]
createLine( 'diag_WEB12',  S1, S2 )

diag_WEB10 = ['diag_WEB10']
diag_WEB11 = ['diag_WEB11']
diag_WEB12 = ['diag_WEB12']



# DEFINE PROPERTIES FOR THE CONCRETE GEOMETRY AND MATERIAL
addMaterial( "Concrete", "CONCR", "TSCR", [] )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/YOUNG", YOUNGSMOD )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/POISON", POISSONRATIO )
setParameter( MATERIAL, "Concrete", "MODTYP/TOTCRK", "FIXED" )
setParameter( MATERIAL, "Concrete", "COMPRS/COMCRV", "PARABO" ) 

setParameter( MATERIAL, "Concrete", "COMPRS/COMSTR", FC )
setParameter( MATERIAL, "Concrete", "COMPRS/GC", GC )
setParameter( MATERIAL, "Concrete", "COMPRS/CONFIN/CNFCRV", "VECCHI" )  
setParameter( MATERIAL, "Concrete", "COMPRS/REDUCT/REDCRV", "VC1993" )

setParameter( MATERIAL, "Concrete", "TENSIL/TENCRV", "MC2010" ) 
setParameter( MATERIAL, "Concrete", "TENSIL/TENSTR", FCT )
setParameter( MATERIAL, "Concrete", "TENSIL/GF1", GF )
setParameter( MATERIAL, "Concrete", "TENSIL/POISRE/POIRED", "DAMAGE" )

setParameter( MATERIAL, "Concrete", "SHEAR/SHRCRV", "DAMAGE" ) 
#setParameter( MATERIAL, "Concrete", "SHEAR/BETA", BETA )    

CONMATNAME = "Concrete"
addGeometry( CONMATNAME, "SHEET", "MEMBRA", [] )
setParameter( GEOMET, CONMATNAME, "THICK", WIDTH )  
assignMaterial( CONMATNAME, "SHAPE", SHAPELIST[0:72] )
assignGeometry( CONMATNAME, "SHAPE", SHAPELIST[0:72] )

#DEFINE PROPERTIES FOR THE STEEL GEOMETRY AND MATERIAL IN THE SUPPORT AND LOAD PLATES
addMaterial( "Steelplate", "MCSTEL", "TRESCA", [] ) 
setParameter( MATERIAL, "Steelplate", "TREPLA/YIELD", "VMISES" )
setParameter( MATERIAL, "Steelplate", "LINEAR/ELASTI/YOUNG", E_steelplate)  
setParameter( MATERIAL, "Steelplate", "LINEAR/ELASTI/POISON", POISSONRATIO_STEEL )
setParameter( MATERIAL, "Steelplate", "TREPLA/YLDSTR", FY_steelplate )


SMATNAME_STEELPLATE = "Steelplate"
addGeometry( SMATNAME_STEELPLATE, "SHEET", "MEMBRA", [] )
setParameter( GEOMET, SMATNAME_STEELPLATE, "THICK", WIDTH )

# ASSIGN MATERIAL FOR STEEL SUPPORT/LOAD PLATES 
assignMaterial( SMATNAME_STEELPLATE, "SHAPE", SHAPELIST[72:82] )
assignGeometry( SMATNAME_STEELPLATE, "SHAPE", SHAPELIST[72:82] )

# DEFINE PROPERTIES FOR THE REINFORCEMENT GEOMETRY AND MATERIAL
setReinforcementAspects( MAINREINF )
setReinforcementAspects( REINF1 )
setReinforcementAspects( REINF2 )
setReinforcementAspects( REINF3 )
setReinforcementAspects( REINF4 )
setReinforcementAspects( REINF5 )
setReinforcementAspects( HOR_WEB1 )
setReinforcementAspects( HOR_WEB2 )
setReinforcementAspects( VERT_WEB1 )
setReinforcementAspects( VERT_WEB2 )
setReinforcementAspects( VERT_WEB3 )
setReinforcementAspects( VERT_WEB4 )
setReinforcementAspects( VERT_WEB5 )
setReinforcementAspects( VERT_WEB6 )
setReinforcementAspects( VERT_WEB7 )
setReinforcementAspects( VERT_WEB8 )
setReinforcementAspects( VERT_WEB9 )
setReinforcementAspects( VERT_WEB10 )
setReinforcementAspects( VERT_WEB11 )
setReinforcementAspects( VERT_WEB12 )
setReinforcementAspects( VERT_WEB13 )
setReinforcementAspects( VERT_WEB14 )
setReinforcementAspects( VERT_WEB15 )
setReinforcementAspects( VERT_WEB16 )
setReinforcementAspects( VERT_WEB17 )
setReinforcementAspects( VERT_WEB18 )
setReinforcementAspects( VERT_WEB19 )

setReinforcementAspects( diag_WEB1 )
setReinforcementAspects( diag_WEB2 )
setReinforcementAspects( diag_WEB3 )
setReinforcementAspects( diag_WEB4 )
setReinforcementAspects( diag_WEB5 )
setReinforcementAspects( diag_WEB6 )
setReinforcementAspects( diag_WEB7 )
setReinforcementAspects( diag_WEB8 )
setReinforcementAspects( diag_WEB9 )
setReinforcementAspects( diag_WEB10 )
setReinforcementAspects( diag_WEB11 )
setReinforcementAspects( diag_WEB12 )

SMATNAME_MAIN = "Main Steel reinforcement"
SMATNAME_10 = "Top Steel reinforcement"
SMATNAME_HOR = "Horizontal Stirrups"
SMATNAME_VERT_10 = "Vertical Stirrups_10"
SMATNAME_VERT_6 = "Vertical Stirrups_6"
SMATNAME_10_diag = "Diagonal inclined reinforcement"

#SMAX AND EPSPLMAX ARE THE PARAMETERS FOR THE LINEAR HARDENING RELATION BETWEEN YIELD STRESS AND PLASTIC STRAIN
SMAX_MAIN = FY_19+ EHTOT1*(EPSMAX - FY_19/ES_19)
SMAX_10 = FY_10 + EHTOT2*(EPSMAX - FY_10/ES_10)
SMAX_WEB_HOR = FY_6 + EHTOT3*(EPSMAX - FY_6/ES_6)
SMAX_WEB_VERT_6 = FY_6 + EHTOT3*(EPSMAX - FY_6/ES_6)
SMAX_WEB_VERT_10 = FY_10 + EHTOT2*(EPSMAX - FY_10/ES_10)

EPSPLMAX_MAIN = EPSMAX*(1-EHTOT1/ES_19) + FY_19/ES_19*(EHTOT1/ES_19 - 1)
EPSPLMAX_10 = EPSMAX*(1-EHTOT2/ES_10) + FY_10/ES_10*(EHTOT2/ES_10 - 1)
EPSPLMAX_WEB_HOR = EPSMAX*(1-EHTOT3/ES_6) + FY_6/ES_6*(EHTOT3/ES_6 - 1)
EPSPLMAX_WEB_VERT_6 = EPSMAX*(1-EHTOT3/ES_6) + FY_6/ES_6*(EHTOT3/ES_6 - 1)
EPSPLMAX_WEB_VERT_10 = EPSMAX*(1-EHTOT2/ES_10) + FY_10/ES_10*(EHTOT2/ES_10 - 1)

addMaterial( SMATNAME_10, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_10, "LINEAR/ELASTI/YOUNG", ES_10 )
setParameter( MATERIAL, SMATNAME_10, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_10, "PLASTI/HARDI2/KAPSIG", [ 0, FY_10, EPSPLMAX_10, SMAX_10 ] )

addMaterial( SMATNAME_MAIN, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_MAIN, "LINEAR/ELASTI/YOUNG", ES_19 )
setParameter( MATERIAL, SMATNAME_MAIN, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_MAIN, "PLASTI/HARDI2/KAPSIG", [ 0, FY_19, EPSPLMAX_MAIN, SMAX_MAIN ] )

addMaterial( SMATNAME_HOR, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_HOR, "LINEAR/ELASTI/YOUNG", ES_6 )
setParameter( MATERIAL, SMATNAME_HOR, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_HOR, "PLASTI/HARDI2/KAPSIG", [ 0, FY_6, EPSPLMAX_WEB_HOR, SMAX_WEB_HOR ] )

addMaterial( SMATNAME_VERT_10, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_VERT_10, "LINEAR/ELASTI/YOUNG", ES_10 )
setParameter( MATERIAL, SMATNAME_VERT_10, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_VERT_10, "PLASTI/HARDI2/KAPSIG", [ 0, FY_10, EPSPLMAX_WEB_VERT_10, SMAX_WEB_VERT_10 ] )

addMaterial( SMATNAME_VERT_6, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_VERT_6, "LINEAR/ELASTI/YOUNG", ES_6 )
setParameter( MATERIAL, SMATNAME_VERT_6, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_VERT_6, "PLASTI/HARDI2/KAPSIG", [ 0, FY_6, EPSPLMAX_WEB_VERT_6, SMAX_WEB_VERT_6 ] )

addMaterial( SMATNAME_10_diag, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_10_diag, "LINEAR/ELASTI/YOUNG", ES_10 )
setParameter( MATERIAL, SMATNAME_10_diag, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_10_diag, "PLASTI/HARDI2/KAPSIG", [ 0, FY_10, EPSPLMAX_10, SMAX_10 ] )


# ADD MATERIAL FOR REINFORCEMENT 
addGeometry( SMATNAME_MAIN, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_MAIN, "CROSSE", ASL_19 )

addGeometry( SMATNAME_10, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_10, "CROSSE", ASL_10)

addGeometry( SMATNAME_HOR, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_HOR, "CROSSE", ASSHOR )

addGeometry( SMATNAME_VERT_10, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_VERT_10, "CROSSE", ASSVERT_10 )

addGeometry( SMATNAME_VERT_6, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_VERT_6, "CROSSE", ASSVERT_6 )

addGeometry( SMATNAME_10_diag, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_10_diag, "CROSSE", ASL_inclined )

#ASSIGN MATERIAL FOR REINFORCEMENT
assignMaterial( SMATNAME_MAIN, "SHAPE", MAINREINF )
assignGeometry( SMATNAME_MAIN, "SHAPE", MAINREINF )

assignMaterial( SMATNAME_10, "SHAPE", REINF1 )
assignGeometry( SMATNAME_10, "SHAPE", REINF1 )

assignMaterial( SMATNAME_10, "SHAPE", REINF2 )
assignGeometry( SMATNAME_10, "SHAPE", REINF2 )

assignMaterial( SMATNAME_10, "SHAPE", REINF3 )
assignGeometry( SMATNAME_10, "SHAPE", REINF3 )

assignMaterial( SMATNAME_10, "SHAPE", REINF4 )
assignGeometry( SMATNAME_10, "SHAPE", REINF4 )

assignMaterial( SMATNAME_10, "SHAPE", REINF5 )
assignGeometry( SMATNAME_10, "SHAPE", REINF5 )

assignMaterial( SMATNAME_HOR, "SHAPE", HOR_WEB1 )
assignGeometry( SMATNAME_HOR, "SHAPE", HOR_WEB1 )
assignMaterial( SMATNAME_HOR, "SHAPE", HOR_WEB2 )
assignGeometry( SMATNAME_HOR, "SHAPE", HOR_WEB2 )

assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB1 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB1 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB2 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB2 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB3 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB3 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB4 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB4 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB5 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB5 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB6 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB6 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB7 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB7 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB8 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB8 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB9 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB9 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB10 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB10 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB11 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB11 )
assignMaterial( SMATNAME_VERT_10, "SHAPE", VERT_WEB12 )
assignGeometry( SMATNAME_VERT_10, "SHAPE", VERT_WEB12 )

assignMaterial( SMATNAME_VERT_6, "SHAPE", VERT_WEB13 )
assignGeometry( SMATNAME_VERT_6, "SHAPE", VERT_WEB13 )
assignMaterial( SMATNAME_VERT_6, "SHAPE", VERT_WEB14 )
assignGeometry( SMATNAME_VERT_6, "SHAPE", VERT_WEB14 )
assignMaterial( SMATNAME_VERT_6, "SHAPE", VERT_WEB15 )
assignGeometry( SMATNAME_VERT_6, "SHAPE", VERT_WEB15 )
assignMaterial( SMATNAME_VERT_6, "SHAPE", VERT_WEB16 )
assignGeometry( SMATNAME_VERT_6, "SHAPE", VERT_WEB16 )
assignMaterial( SMATNAME_VERT_6, "SHAPE", VERT_WEB17 )
assignGeometry( SMATNAME_VERT_6, "SHAPE", VERT_WEB17 )
assignMaterial( SMATNAME_VERT_6, "SHAPE", VERT_WEB18 )
assignGeometry( SMATNAME_VERT_6, "SHAPE", VERT_WEB18 )
assignMaterial( SMATNAME_VERT_6, "SHAPE", VERT_WEB19 )
assignGeometry( SMATNAME_VERT_6, "SHAPE", VERT_WEB19 )

assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB1 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB1 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB2 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB2 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB3 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB3 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB4 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB4 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB5 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB5 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB6 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB6 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB7 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB7 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB8 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB8 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB9 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB9 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB10 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB10 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB11 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB11 )
assignGeometry( SMATNAME_10_diag, "SHAPE", diag_WEB12 )
assignMaterial( SMATNAME_10_diag, "SHAPE", diag_WEB12 )

# DEFINE SUPPORTS
createPointSupport( "LEFTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "TRANSL", [ 0, 1, 1 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "RIGHTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "TRANSL", [ 1, 1, 1] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

attach( GEOMETRYSUPPORT, "LEFTSUPPORT", "SHEET74", [[ 150, 0, 0 ]] )
attach( GEOMETRYSUPPORT, "RIGHTSUPPORT", "SHEET76", [[ 1050, 0, 0 ]]  )

COORDLEFTSUPPORT = [150, 0, 0 ]
COORDRIGHTSUPPORT = [ 1050, 0, 0 ]


#DEFINE SUPPORT IN LOADPLATES
addSet( GEOMETRYSUPPORTSET, "Loadsupport" )
createPointSupport( "Loadsupport", "Loadsupport" )
setParameter( GEOMETRYSUPPORT, "Loadsupport", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "Loadsupport", "TRANSL", [ 0, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "Loadsupport", "ROTATI", [ 0, 0, 0 ] )
attach( GEOMETRYSUPPORT, "Loadsupport", "SHEET78", [[ 450, 700, 0 ]] )
attach( GEOMETRYSUPPORT, "Loadsupport", "SHEET80", [[ 750, 700, 0 ]] )



#DISPLACEMENT CONTROL 
addSet( GEOMETRYLOADSET, "Geometry load case 2" )
showView( "GEOM" )
createPointLoad( "Displacement control", "Geometry load case 2" )
setParameter( GEOMETRYLOAD, "Displacement control", "LODTYP", "DEFORM" )
setParameter( GEOMETRYLOAD, "Displacement control", "DEFORM/TR/VALUE", PRESCRIBEDDISPLACEMENT )
setParameter( GEOMETRYLOAD, "Displacement control", "DEFORM/TR/DIRECT", 2 )
attach( GEOMETRYLOAD, "Displacement control", "SHEET78", [[ 450, 700, 0 ]] ) 
attach( GEOMETRYLOAD, "Displacement control", "SHEET80", [[ 750, 700, 0 ]] )

# MESHING
setElementSize( SHAPELIST, ELEMENTSIZE )
setElementClassType( SHAPELIST, "MEMBRA" )
generateMesh(shapes())
addElementData( "Element data 1" )
setParameter( DATA, "Element data 1", "INTEGR", "HIGH" ) 
assignElementData( "Element data 1", ELEMENT, SHAPELIST )

# SET UP NON-LINEAR ANALYSIS
analysis = "NLFEA_T3-3_solution_strategy"
command  = "Structural nonlinear"
addAnalysis( analysis )
addAnalysisCommand( analysis, "NONLIN", command )

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/METNAM", "NEWTON" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/NEWTON/TYPNAM", "REGULA" ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/MAXITE", 40 ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/DISPLA", False )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/TOLCON", 0.01 ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/NOCONV", "CONTIN" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/TOLCON", 0.001 ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/NOCONV", "CONTIN" ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/SIMULT", False )
# addAnalysisCommandDetail( analysis, command, "EXECUT(1)/SOLVE/CHOLES" )
addAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE" )    
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE", True )     
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/MAXLS", 10 )     

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/SIZES", "0.01(100)") 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/AMOUNT", "FULL" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/TERMIN", "STEP" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELTYP", "USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/FORCE" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)/TOTAL/GREEN/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(2)/TOTAL/GREEN/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(2)/TOTAL/GREEN/PRINCI/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(3)/CRACK/GREEN" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(2)/TOTAL/CAUCHY/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(2)/TOTAL/CAUCHY/PRINCI/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA(4)/INCREM/TRANSL/GLOBAL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(5)/CRKWDT/GREEN/PRINCI" )

addAnalysisCommandDetail( analysis, command, "OUTPUT" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(2)/DEVICE", "TABULA" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(2)/SELECT/MODSEL", "USER" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(2)/SELECT/NODES(1)/RNGNRS", "ALL" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(2)/SELECT/ELEMEN(1)/RNGNRS", "NONE" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(2)/SELTYP", "USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(2)/USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(2)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(2)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(2)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/COORDI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(2)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/COORDI", True )

# EXPORT .DAT- AND .DCF-FILE
exportModel( "T3-3_displ.dat", 5 )
saveAnalysisCommands( analysis, "T3-3_displ.dcf")

# RUN ANALYSIS
runSolver( analysis )
showView( "RESULT" )
setViewPoint( "TOP" )
setResultPlot( "contours", "Cauchy Total Stresses/mappedintegrationpoint", "S2" )

# FIND LOAD DISPLACEMENT CURVE
DISPCOORD = [0.5*XCOORD[19],YCOORD[1], 0 ]
DISPNODE = findNearestNodes([DISPCOORD])

FORCENODE1 = findNearestNodes([COORDLEFTSUPPORT])
FORCENODE2 = findNearestNodes([COORDRIGHTSUPPORT])
FORCENODES = [FORCENODE1[0],FORCENODE2[0]]

DISPLACEMENTS = []
LASTCASE = len(resultCases(analysis,''))
for i in range(0,LASTCASE):
    DISPLACEMENTS.append(resultData([analysis,"Output",resultCases(analysis,"Output")[i],"Displacements","TDtY"],DISPNODE)[0][1])

REACTIONS = []
FORCE = 0
for i in range(0,LASTCASE):
    for j in FORCENODES:
        FORCE = FORCE + resultData([analysis,"Output",resultCases(analysis,"Output")[i],"Reaction Forces","FBY"],(j,))[0][1]
    REACTIONS.append(FORCE)  
    FORCE = 0 
f = open('LOADDISP_T3-3.TXT','w')
for i in range(0,len(REACTIONS)):
    f.write('{0:20.6f} {1:20.6f}\n'.format(DISPLACEMENTS[i],REACTIONS[i]))

f.close()

